@@ -1,7 +1,7 @@
 __all__ = (
     'start', 'sleep_forever', 'Event', 'Task', 'TaskState',
     'get_current_task', 'get_step_coro', 'aclosing', 'Awaitable_or_Task',
-    'raw_start', 'cancel_protection',
+    'raw_start', 'cancel_protection', 'dummy_task', 'checkpoint',
 )
 
 import itertools
@@ -135,6 +135,8 @@ class Task:
                     coro.close()
         else:
             coro.close()
+            if self._state is TaskState.CREATED:
+                self._state = TaskState.CANCELLED
 
     # give 'cancel()' an alias so that we can cancel tasks just like we close
     # coroutines.
@@ -142,9 +144,7 @@ class Task:
 
     @property
     def _is_cancellable(self) -> bool:
-        '''
-        Indicates whether the task can be immediately cancellable.
-        '''
+        '''Whether the task can immediately be cancelled.'''
         return (not self._cancel_protection) and \
             getcoroutinestate(self._root_coro) != CORO_RUNNING
 
@@ -180,6 +180,17 @@ async def cancel_protection():
         task._cancel_protection -= 1
 
 
+async def checkpoint():
+    '''
+    (experimental) If the ``.cancel()`` method of the current task has been
+    called and the task is not protected from cancellation, cancels the task
+    immediately. Otherwise, does nothing.
+    '''
+    task = await get_current_task()
+    if task._cancel_called and not task._cancel_protection:
+        await sleep_forever()
+
+
 Awaitable_or_Task = typing.Union[typing.Awaitable, Task]
 
 
@@ -292,7 +303,7 @@ def get_step_coro():
     return (yield lambda step_coro: step_coro(step_coro))[0][0]
 
 
-async def get_current_task():
+async def get_current_task() -> typing.Optional[Task]:
     '''Returns the task currently running. None if no Task is associated,
     which happens when ``raw_start()`` is used.'''
     return getattr(await get_step_coro(), '__self__', None)
@@ -306,3 +317,7 @@ async def aclosing(aiter):
         yield aiter
     finally:
         await aiter.aclose()
+
+
+dummy_task = Task(sleep_forever(), name='asyncgui.dummy_task')
+dummy_task.cancel()
